# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.address import Address
from paypalserversdk.models.name import Name
from paypalserversdk.models.pay_pal_wallet_attributes import PayPalWalletAttributes
from paypalserversdk.models.pay_pal_wallet_experience_context import PayPalWalletExperienceContext
from paypalserversdk.models.phone_with_type import PhoneWithType
from paypalserversdk.models.tax_info import TaxInfo


class PayPalWallet(object):

    """Implementation of the 'PayPal Wallet' model.

    A resource that identifies a PayPal Wallet is used for payment.

    Attributes:
        vault_id (str): The PayPal-generated ID for the vaulted payment
            source. This ID should be stored on the merchant's server so the
            saved payment source can be used for future transactions.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign
            exists.</blockquote>
        name (Name): The name of the party.
        phone (PhoneWithType): The phone information.
        birth_date (str): The stand-alone date, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). To
            represent special legal values, such as a date of birth, you
            should use dates with no associated time or time-zone data.
            Whenever possible, use the standard `date_time` type. This regular
            expression does not validate all dates. For example, February 31
            is valid and nothing is known about leap years.
        tax_info (TaxInfo): The tax ID of the customer. The customer is also
            known as the payer. Both `tax_id` and `tax_id_type` are required.
        address (Address): The portable international postal address. Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).
        attributes (PayPalWalletAttributes): Additional attributes associated
            with the use of this PayPal Wallet.
        experience_context (PayPalWalletExperienceContext): Customizes the
            payer experience during the approval process for payment with
            PayPal.<blockquote><strong>Note:</strong> Partners and
            Marketplaces might configure <code>brand_name</code> and
            <code>shipping_preference</code> during partner account setup,
            which overrides the request values.</blockquote>
        billing_agreement_id (str): The PayPal billing agreement ID.
            References an approved recurring payment for goods or services.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vault_id": 'vault_id',
        "email_address": 'email_address',
        "name": 'name',
        "phone": 'phone',
        "birth_date": 'birth_date',
        "tax_info": 'tax_info',
        "address": 'address',
        "attributes": 'attributes',
        "experience_context": 'experience_context',
        "billing_agreement_id": 'billing_agreement_id'
    }

    _optionals = [
        'vault_id',
        'email_address',
        'name',
        'phone',
        'birth_date',
        'tax_info',
        'address',
        'attributes',
        'experience_context',
        'billing_agreement_id',
    ]

    def __init__(self,
                 vault_id=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 phone=APIHelper.SKIP,
                 birth_date=APIHelper.SKIP,
                 tax_info=APIHelper.SKIP,
                 address=APIHelper.SKIP,
                 attributes=APIHelper.SKIP,
                 experience_context=APIHelper.SKIP,
                 billing_agreement_id=APIHelper.SKIP):
        """Constructor for the PayPalWallet class"""

        # Initialize members of the class
        if vault_id is not APIHelper.SKIP:
            self.vault_id = vault_id 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if name is not APIHelper.SKIP:
            self.name = name 
        if phone is not APIHelper.SKIP:
            self.phone = phone 
        if birth_date is not APIHelper.SKIP:
            self.birth_date = birth_date 
        if tax_info is not APIHelper.SKIP:
            self.tax_info = tax_info 
        if address is not APIHelper.SKIP:
            self.address = address 
        if attributes is not APIHelper.SKIP:
            self.attributes = attributes 
        if experience_context is not APIHelper.SKIP:
            self.experience_context = experience_context 
        if billing_agreement_id is not APIHelper.SKIP:
            self.billing_agreement_id = billing_agreement_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vault_id = dictionary.get("vault_id") if dictionary.get("vault_id") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        name = Name.from_dictionary(dictionary.get('name')) if 'name' in dictionary.keys() else APIHelper.SKIP
        phone = PhoneWithType.from_dictionary(dictionary.get('phone')) if 'phone' in dictionary.keys() else APIHelper.SKIP
        birth_date = dictionary.get("birth_date") if dictionary.get("birth_date") else APIHelper.SKIP
        tax_info = TaxInfo.from_dictionary(dictionary.get('tax_info')) if 'tax_info' in dictionary.keys() else APIHelper.SKIP
        address = Address.from_dictionary(dictionary.get('address')) if 'address' in dictionary.keys() else APIHelper.SKIP
        attributes = PayPalWalletAttributes.from_dictionary(dictionary.get('attributes')) if 'attributes' in dictionary.keys() else APIHelper.SKIP
        experience_context = PayPalWalletExperienceContext.from_dictionary(dictionary.get('experience_context')) if 'experience_context' in dictionary.keys() else APIHelper.SKIP
        billing_agreement_id = dictionary.get("billing_agreement_id") if dictionary.get("billing_agreement_id") else APIHelper.SKIP
        # Return an object of this model
        return cls(vault_id,
                   email_address,
                   name,
                   phone,
                   birth_date,
                   tax_info,
                   address,
                   attributes,
                   experience_context,
                   billing_agreement_id)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaymentAdviceCode(object):

    """Implementation of the 'Payment Advice Code' enum.

    The declined payment transactions might have payment advice codes. The
    card networks, like Visa and Mastercard, return payment advice codes.

    Attributes:
        ENUM_01: TODO: type description here.
        ENUM_02: TODO: type description here.
        ENUM_03: TODO: type description here.
        ENUM_21: TODO: type description here.

    """
    ENUM_01 = '01'

    ENUM_02 = '02'

    ENUM_03 = '03'

    ENUM_21 = '21'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.card_supplementary_data import CardSupplementaryData


class SupplementaryData(object):

    """Implementation of the 'Supplementary Data' model.

    Supplementary data about a payment. This object passes information that
    can be used to improve risk assessments and processing costs, for example,
    by providing Level 2 and Level 3 payment data.

    Attributes:
        card (CardSupplementaryData): Merchants and partners can add Level 2
            and 3 data to payments to reduce risk and payment processing
            costs. For more information about processing payments, see <a
            href="https://developer.paypal.com/docs/checkout/advanced/processin
            g/">checkout</a> or <a
            href="https://developer.paypal.com/docs/multiparty/checkout/advance
            d/processing/">multiparty checkout</a>.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "card": 'card'
    }

    _optionals = [
        'card',
    ]

    def __init__(self,
                 card=APIHelper.SKIP):
        """Constructor for the SupplementaryData class"""

        # Initialize members of the class
        if card is not APIHelper.SKIP:
            self.card = card 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        card = CardSupplementaryData.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(card)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.apple_pay_payment_object import ApplePayPaymentObject
from paypalserversdk.models.bancontact_payment_object import BancontactPaymentObject
from paypalserversdk.models.blik_payment_object import BLIKPaymentObject
from paypalserversdk.models.card_response import CardResponse
from paypalserversdk.models.eps_payment_object import EPSPaymentObject
from paypalserversdk.models.giropay_payment_object import GiropayPaymentObject
from paypalserversdk.models.google_pay_wallet_response import GooglePayWalletResponse
from paypalserversdk.models.ideal_payment_object import IDEALPaymentObject
from paypalserversdk.models.my_bank_payment_object import MyBankPaymentObject
from paypalserversdk.models.p_24_payment_object import P24PaymentObject
from paypalserversdk.models.pay_pal_wallet_response import PayPalWalletResponse
from paypalserversdk.models.sofort_payment_object import SofortPaymentObject
from paypalserversdk.models.trustly_payment_object import TrustlyPaymentObject
from paypalserversdk.models.venmo_wallet_response import VenmoWalletResponse


class PaymentSourceResponse(object):

    """Implementation of the 'Payment Source Response' model.

    The payment source used to fund the payment.

    Attributes:
        card (CardResponse): The payment card to use to fund a payment. Card
            can be a credit or debit card.
        paypal (PayPalWalletResponse): The PayPal Wallet response.
        bancontact (BancontactPaymentObject): Information used to pay
            Bancontact.
        blik (BLIKPaymentObject): Information used to pay using BLIK.
        eps (EPSPaymentObject): Information used to pay using eps.
        giropay (GiropayPaymentObject): Information needed to pay using
            giropay.
        ideal (IDEALPaymentObject): Information used to pay using iDEAL.
        mybank (MyBankPaymentObject): Information used to pay using MyBank.
        p_24 (P24PaymentObject): Information used to pay using
            P24(Przelewy24).
        sofort (SofortPaymentObject): Information used to pay using Sofort.
        trustly (TrustlyPaymentObject): Information needed to pay using
            Trustly.
        apple_pay (ApplePayPaymentObject): Information needed to pay using
            ApplePay.
        google_pay (GooglePayWalletResponse): Google Pay Wallet payment data.
        venmo (VenmoWalletResponse): Venmo wallet response.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "card": 'card',
        "paypal": 'paypal',
        "bancontact": 'bancontact',
        "blik": 'blik',
        "eps": 'eps',
        "giropay": 'giropay',
        "ideal": 'ideal',
        "mybank": 'mybank',
        "p_24": 'p24',
        "sofort": 'sofort',
        "trustly": 'trustly',
        "apple_pay": 'apple_pay',
        "google_pay": 'google_pay',
        "venmo": 'venmo'
    }

    _optionals = [
        'card',
        'paypal',
        'bancontact',
        'blik',
        'eps',
        'giropay',
        'ideal',
        'mybank',
        'p_24',
        'sofort',
        'trustly',
        'apple_pay',
        'google_pay',
        'venmo',
    ]

    def __init__(self,
                 card=APIHelper.SKIP,
                 paypal=APIHelper.SKIP,
                 bancontact=APIHelper.SKIP,
                 blik=APIHelper.SKIP,
                 eps=APIHelper.SKIP,
                 giropay=APIHelper.SKIP,
                 ideal=APIHelper.SKIP,
                 mybank=APIHelper.SKIP,
                 p_24=APIHelper.SKIP,
                 sofort=APIHelper.SKIP,
                 trustly=APIHelper.SKIP,
                 apple_pay=APIHelper.SKIP,
                 google_pay=APIHelper.SKIP,
                 venmo=APIHelper.SKIP):
        """Constructor for the PaymentSourceResponse class"""

        # Initialize members of the class
        if card is not APIHelper.SKIP:
            self.card = card 
        if paypal is not APIHelper.SKIP:
            self.paypal = paypal 
        if bancontact is not APIHelper.SKIP:
            self.bancontact = bancontact 
        if blik is not APIHelper.SKIP:
            self.blik = blik 
        if eps is not APIHelper.SKIP:
            self.eps = eps 
        if giropay is not APIHelper.SKIP:
            self.giropay = giropay 
        if ideal is not APIHelper.SKIP:
            self.ideal = ideal 
        if mybank is not APIHelper.SKIP:
            self.mybank = mybank 
        if p_24 is not APIHelper.SKIP:
            self.p_24 = p_24 
        if sofort is not APIHelper.SKIP:
            self.sofort = sofort 
        if trustly is not APIHelper.SKIP:
            self.trustly = trustly 
        if apple_pay is not APIHelper.SKIP:
            self.apple_pay = apple_pay 
        if google_pay is not APIHelper.SKIP:
            self.google_pay = google_pay 
        if venmo is not APIHelper.SKIP:
            self.venmo = venmo 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        card = CardResponse.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        paypal = PayPalWalletResponse.from_dictionary(dictionary.get('paypal')) if 'paypal' in dictionary.keys() else APIHelper.SKIP
        bancontact = BancontactPaymentObject.from_dictionary(dictionary.get('bancontact')) if 'bancontact' in dictionary.keys() else APIHelper.SKIP
        blik = BLIKPaymentObject.from_dictionary(dictionary.get('blik')) if 'blik' in dictionary.keys() else APIHelper.SKIP
        eps = EPSPaymentObject.from_dictionary(dictionary.get('eps')) if 'eps' in dictionary.keys() else APIHelper.SKIP
        giropay = GiropayPaymentObject.from_dictionary(dictionary.get('giropay')) if 'giropay' in dictionary.keys() else APIHelper.SKIP
        ideal = IDEALPaymentObject.from_dictionary(dictionary.get('ideal')) if 'ideal' in dictionary.keys() else APIHelper.SKIP
        mybank = MyBankPaymentObject.from_dictionary(dictionary.get('mybank')) if 'mybank' in dictionary.keys() else APIHelper.SKIP
        p_24 = P24PaymentObject.from_dictionary(dictionary.get('p24')) if 'p24' in dictionary.keys() else APIHelper.SKIP
        sofort = SofortPaymentObject.from_dictionary(dictionary.get('sofort')) if 'sofort' in dictionary.keys() else APIHelper.SKIP
        trustly = TrustlyPaymentObject.from_dictionary(dictionary.get('trustly')) if 'trustly' in dictionary.keys() else APIHelper.SKIP
        apple_pay = ApplePayPaymentObject.from_dictionary(dictionary.get('apple_pay')) if 'apple_pay' in dictionary.keys() else APIHelper.SKIP
        google_pay = GooglePayWalletResponse.from_dictionary(dictionary.get('google_pay')) if 'google_pay' in dictionary.keys() else APIHelper.SKIP
        venmo = VenmoWalletResponse.from_dictionary(dictionary.get('venmo')) if 'venmo' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(card,
                   paypal,
                   bancontact,
                   blik,
                   eps,
                   giropay,
                   ideal,
                   mybank,
                   p_24,
                   sofort,
                   trustly,
                   apple_pay,
                   google_pay,
                   venmo)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.cobranded_card import CobrandedCard
from paypalserversdk.models.pay_pal_wallet_vault_response import PayPalWalletVaultResponse


class PayPalWalletAttributesResponse(object):

    """Implementation of the 'PayPal Wallet Attributes Response' model.

    Additional attributes associated with the use of a PayPal Wallet.

    Attributes:
        vault (PayPalWalletVaultResponse): The details about a saved PayPal
            Wallet payment source.
        cobranded_cards (List[CobrandedCard]): An array of merchant cobranded
            cards used by buyer to complete an order. This array will be
            present if a merchant has onboarded their cobranded card with
            PayPal and provided corresponding label(s).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vault": 'vault',
        "cobranded_cards": 'cobranded_cards'
    }

    _optionals = [
        'vault',
        'cobranded_cards',
    ]

    def __init__(self,
                 vault=APIHelper.SKIP,
                 cobranded_cards=APIHelper.SKIP):
        """Constructor for the PayPalWalletAttributesResponse class"""

        # Initialize members of the class
        if vault is not APIHelper.SKIP:
            self.vault = vault 
        if cobranded_cards is not APIHelper.SKIP:
            self.cobranded_cards = cobranded_cards 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vault = PayPalWalletVaultResponse.from_dictionary(dictionary.get('vault')) if 'vault' in dictionary.keys() else APIHelper.SKIP
        cobranded_cards = None
        if dictionary.get('cobranded_cards') is not None:
            cobranded_cards = [CobrandedCard.from_dictionary(x) for x in dictionary.get('cobranded_cards')]
        else:
            cobranded_cards = APIHelper.SKIP
        # Return an object of this model
        return cls(vault,
                   cobranded_cards)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VenmoPaymentTokenCustomerType(object):

    """Implementation of the 'Venmo Payment Token Customer Type' enum.

    The customer type associated with the Venmo payment token. This is to
    indicate whether the customer acting on the merchant / platform is either
    a business or a consumer.

    Attributes:
        CONSUMER: TODO: type description here.
        BUSINESS: TODO: type description here.

    """
    CONSUMER = 'CONSUMER'

    BUSINESS = 'BUSINESS'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class FullfillmentType(object):

    """Implementation of the 'Fullfillment Type' enum.

    A classification for the method of purchase fulfillment (e.g shipping,
    in-store pickup, etc). Either `type` or `options` may be present, but not
    both.

    Attributes:
        SHIPPING: TODO: type description here.
        PICKUP_IN_PERSON: TODO: type description here.
        PICKUP_IN_STORE: TODO: type description here.
        PICKUP_FROM_PERSON: TODO: type description here.

    """
    SHIPPING = 'SHIPPING'

    PICKUP_IN_PERSON = 'PICKUP_IN_PERSON'

    PICKUP_IN_STORE = 'PICKUP_IN_STORE'

    PICKUP_FROM_PERSON = 'PICKUP_FROM_PERSON'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class NetworkTransactionReference(object):

    """Implementation of the 'Network Transaction Reference' model.

    Reference values used by the card network to identify a transaction.

    Attributes:
        id (str): Transaction reference id returned by the scheme. For Visa
            and Amex, this is the "Tran id" field in response. For MasterCard,
            this is the "BankNet reference id" field in response. For
            Discover, this is the "NRID" field in response. The pattern we
            expect for this field from Visa/Amex/CB/Discover is numeric,
            Mastercard/BNPP is alphanumeric and Paysecure is alphanumeric with
            special character -.
        date (str): The date that the transaction was authorized by the
            scheme. This field may not be returned for all networks.
            MasterCard refers to this field as "BankNet reference date.
        network (CardBrand): The card network or brand. Applies to credit,
            debit, gift, and payment cards.
        acquirer_reference_number (str): Reference ID issued for the card
            transaction. This ID can be used to track the transaction across
            processors, card brands and issuing banks.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "date": 'date',
        "network": 'network',
        "acquirer_reference_number": 'acquirer_reference_number'
    }

    _optionals = [
        'date',
        'network',
        'acquirer_reference_number',
    ]

    def __init__(self,
                 id=None,
                 date=APIHelper.SKIP,
                 network=APIHelper.SKIP,
                 acquirer_reference_number=APIHelper.SKIP):
        """Constructor for the NetworkTransactionReference class"""

        # Initialize members of the class
        self.id = id 
        if date is not APIHelper.SKIP:
            self.date = date 
        if network is not APIHelper.SKIP:
            self.network = network 
        if acquirer_reference_number is not APIHelper.SKIP:
            self.acquirer_reference_number = acquirer_reference_number 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else None
        date = dictionary.get("date") if dictionary.get("date") else APIHelper.SKIP
        network = dictionary.get("network") if dictionary.get("network") else APIHelper.SKIP
        acquirer_reference_number = dictionary.get("acquirer_reference_number") if dictionary.get("acquirer_reference_number") else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   date,
                   network,
                   acquirer_reference_number)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderStatus(object):

    """Implementation of the 'Order Status' enum.

    The order status.

    Attributes:
        CREATED: TODO: type description here.
        SAVED: TODO: type description here.
        APPROVED: TODO: type description here.
        VOIDED: TODO: type description here.
        COMPLETED: TODO: type description here.
        PAYER_ACTION_REQUIRED: TODO: type description here.

    """
    CREATED = 'CREATED'

    SAVED = 'SAVED'

    APPROVED = 'APPROVED'

    VOIDED = 'VOIDED'

    COMPLETED = 'COMPLETED'

    PAYER_ACTION_REQUIRED = 'PAYER_ACTION_REQUIRED'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class BinDetails(object):

    """Implementation of the 'Bin Details' model.

    Bank Identification Number (BIN) details used to fund a payment.

    Attributes:
        bin (str): The Bank Identification Number (BIN) signifies the number
            that is being used to identify the granular level details (except
            the PII information) of the card.
        issuing_bank (str): The issuer of the card instrument.
        bin_country_code (str): The [two-character ISO 3166-1
            code](/api/rest/reference/country-codes/) that identifies the
            country or region.<blockquote><strong>Note:</strong> The country
            code for Great Britain is <code>GB</code> and not <code>UK</code>
            as used in the top-level domain names for that country. Use the
            `C2` country code for China worldwide for comparable uncontrolled
            price (CUP) method, bank card, and cross-border
            transactions.</blockquote>
        products (List[str]): The type of card product assigned to the BIN by
            the issuer. These values are defined by the issuer and may change
            over time. Some examples include: PREPAID_GIFT, CONSUMER,
            CORPORATE.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "bin": 'bin',
        "issuing_bank": 'issuing_bank',
        "bin_country_code": 'bin_country_code',
        "products": 'products'
    }

    _optionals = [
        'bin',
        'issuing_bank',
        'bin_country_code',
        'products',
    ]

    def __init__(self,
                 bin=APIHelper.SKIP,
                 issuing_bank=APIHelper.SKIP,
                 bin_country_code=APIHelper.SKIP,
                 products=APIHelper.SKIP):
        """Constructor for the BinDetails class"""

        # Initialize members of the class
        if bin is not APIHelper.SKIP:
            self.bin = bin 
        if issuing_bank is not APIHelper.SKIP:
            self.issuing_bank = issuing_bank 
        if bin_country_code is not APIHelper.SKIP:
            self.bin_country_code = bin_country_code 
        if products is not APIHelper.SKIP:
            self.products = products 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        bin = dictionary.get("bin") if dictionary.get("bin") else APIHelper.SKIP
        issuing_bank = dictionary.get("issuing_bank") if dictionary.get("issuing_bank") else APIHelper.SKIP
        bin_country_code = dictionary.get("bin_country_code") if dictionary.get("bin_country_code") else APIHelper.SKIP
        products = dictionary.get("products") if dictionary.get("products") else APIHelper.SKIP
        # Return an object of this model
        return cls(bin,
                   issuing_bank,
                   bin_country_code,
                   products)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RefundIncompleteReason(object):

    """Implementation of the 'Refund Incomplete Reason' enum.

    The reason why the refund has the `PENDING` or `FAILED` status.

    Attributes:
        ECHECK: TODO: type description here.

    """
    ECHECK = 'ECHECK'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.amount_with_breakdown import AmountWithBreakdown
from paypalserversdk.models.item import Item
from paypalserversdk.models.payee import Payee
from paypalserversdk.models.payment_instruction import PaymentInstruction
from paypalserversdk.models.shipping_details import ShippingDetails
from paypalserversdk.models.supplementary_data import SupplementaryData


class PurchaseUnitRequest(object):

    """Implementation of the 'Purchase Unit Request' model.

    The purchase unit request. Includes required information for the payment
    contract.

    Attributes:
        reference_id (str): The API caller-provided external ID for the
            purchase unit. Required for multiple purchase units when you must
            update the order through `PATCH`. If you omit this value and the
            order contains only one purchase unit, PayPal sets this value to
            `default`.
        amount (AmountWithBreakdown): The total order amount with an optional
            breakdown that provides details, such as the total item amount,
            total tax amount, shipping, handling, insurance, and discounts, if
            any.<br/>If you specify `amount.breakdown`, the amount equals
            `item_total` plus `tax_total` plus `shipping` plus `handling` plus
            `insurance` minus `shipping_discount` minus discount.<br/>The
            amount must be a positive number. For listed of supported
            currencies and decimal precision, see the PayPal REST APIs <a
            href="/docs/integration/direct/rest/currency-codes/">Currency
            Codes</a>.
        payee (Payee): The merchant who receives the funds and fulfills the
            order. The merchant is also known as the payee.
        payment_instruction (PaymentInstruction): Any additional payment
            instructions to be consider during payment processing. This
            processing instruction is applicable for Capturing an order or
            Authorizing an Order.
        description (str): The purchase description. The maximum length of the
            character is dependent on the type of characters used. The
            character length is specified assuming a US ASCII character.
            Depending on type of character; (e.g. accented character, Japanese
            characters) the number of characters that that can be specified as
            input might not equal the permissible max length.
        custom_id (str): The API caller-provided external ID. Used to
            reconcile client transactions with PayPal transactions. Appears in
            transaction and settlement reports but is not visible to the
            payer.
        invoice_id (str): The API caller-provided external invoice number for
            this order. Appears in both the payer's transaction history and
            the emails that the payer receives.
        soft_descriptor (str): The soft descriptor is the dynamic text used to
            construct the statement descriptor that appears on a payer's card
            statement.<br><br>If an Order is paid using the "PayPal Wallet",
            the statement descriptor will appear in following format on the
            payer's card statement:
            <code><var>PAYPAL_prefix</var>+(space)+<var>merchant_descriptor</va
            r>+(space)+
            <var>soft_descriptor</var></code><blockquote><strong>Note:</strong>
            The merchant descriptor is the descriptor of the merchant’s
            payment receiving preferences which can be seen by logging into
            the merchant account
            https://www.sandbox.paypal.com/businessprofile/settings/info/edit</
            blockquote>The <code>PAYPAL</code> prefix uses 8 characters. Only
            the first 22 characters will be displayed in the statement.
            <br>For example, if:<ul><li>The PayPal prefix toggle is
            <code>PAYPAL *</code>.</li><li>The merchant descriptor in the
            profile is <code>Janes Gift</code>.</li><li>The soft descriptor is
            <code>800-123-1234</code>.</li></ul>Then, the statement descriptor
            on the card is <code>PAYPAL * Janes Gift 80</code>.
        items (List[Item]): An array of items that the customer purchases from
            the merchant.
        shipping (ShippingDetails): The shipping details.
        supplementary_data (SupplementaryData): Supplementary data about a
            payment. This object passes information that can be used to
            improve risk assessments and processing costs, for example, by
            providing Level 2 and Level 3 payment data.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount": 'amount',
        "reference_id": 'reference_id',
        "payee": 'payee',
        "payment_instruction": 'payment_instruction',
        "description": 'description',
        "custom_id": 'custom_id',
        "invoice_id": 'invoice_id',
        "soft_descriptor": 'soft_descriptor',
        "items": 'items',
        "shipping": 'shipping',
        "supplementary_data": 'supplementary_data'
    }

    _optionals = [
        'reference_id',
        'payee',
        'payment_instruction',
        'description',
        'custom_id',
        'invoice_id',
        'soft_descriptor',
        'items',
        'shipping',
        'supplementary_data',
    ]

    def __init__(self,
                 amount=None,
                 reference_id=APIHelper.SKIP,
                 payee=APIHelper.SKIP,
                 payment_instruction=APIHelper.SKIP,
                 description=APIHelper.SKIP,
                 custom_id=APIHelper.SKIP,
                 invoice_id=APIHelper.SKIP,
                 soft_descriptor=APIHelper.SKIP,
                 items=APIHelper.SKIP,
                 shipping=APIHelper.SKIP,
                 supplementary_data=APIHelper.SKIP):
        """Constructor for the PurchaseUnitRequest class"""

        # Initialize members of the class
        if reference_id is not APIHelper.SKIP:
            self.reference_id = reference_id 
        self.amount = amount 
        if payee is not APIHelper.SKIP:
            self.payee = payee 
        if payment_instruction is not APIHelper.SKIP:
            self.payment_instruction = payment_instruction 
        if description is not APIHelper.SKIP:
            self.description = description 
        if custom_id is not APIHelper.SKIP:
            self.custom_id = custom_id 
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if soft_descriptor is not APIHelper.SKIP:
            self.soft_descriptor = soft_descriptor 
        if items is not APIHelper.SKIP:
            self.items = items 
        if shipping is not APIHelper.SKIP:
            self.shipping = shipping 
        if supplementary_data is not APIHelper.SKIP:
            self.supplementary_data = supplementary_data 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = AmountWithBreakdown.from_dictionary(dictionary.get('amount')) if dictionary.get('amount') else None
        reference_id = dictionary.get("reference_id") if dictionary.get("reference_id") else APIHelper.SKIP
        payee = Payee.from_dictionary(dictionary.get('payee')) if 'payee' in dictionary.keys() else APIHelper.SKIP
        payment_instruction = PaymentInstruction.from_dictionary(dictionary.get('payment_instruction')) if 'payment_instruction' in dictionary.keys() else APIHelper.SKIP
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        custom_id = dictionary.get("custom_id") if dictionary.get("custom_id") else APIHelper.SKIP
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        soft_descriptor = dictionary.get("soft_descriptor") if dictionary.get("soft_descriptor") else APIHelper.SKIP
        items = None
        if dictionary.get('items') is not None:
            items = [Item.from_dictionary(x) for x in dictionary.get('items')]
        else:
            items = APIHelper.SKIP
        shipping = ShippingDetails.from_dictionary(dictionary.get('shipping')) if 'shipping' in dictionary.keys() else APIHelper.SKIP
        supplementary_data = SupplementaryData.from_dictionary(dictionary.get('supplementary_data')) if 'supplementary_data' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(amount,
                   reference_id,
                   payee,
                   payment_instruction,
                   description,
                   custom_id,
                   invoice_id,
                   soft_descriptor,
                   items,
                   shipping,
                   supplementary_data)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderTrackerStatus(object):

    """Implementation of the 'Order Tracker Status' enum.

    The status of the item shipment.

    Attributes:
        CANCELLED: TODO: type description here.
        SHIPPED: TODO: type description here.

    """
    CANCELLED = 'CANCELLED'

    SHIPPED = 'SHIPPED'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class GooglePayDecryptedTokenData(object):

    """Implementation of the 'Google Pay Decrypted Token Data' model.

    Details shared by Google for the merchant to be shared with PayPal. This
    is required to process the transaction using the Google Pay payment
    method.

    Attributes:
        message_id (str): A unique ID that identifies the message in case it
            needs to be revoked or located at a later time.
        message_expiration (str): Date and time at which the message expires
            as UTC milliseconds since epoch. Integrators should reject any
            message that's expired.
        payment_method (GooglePayPaymentMethod): The type of the payment
            credential. Currently, only CARD is supported.
        authentication_method (GooglePayAuthenticationMethod): Authentication
            Method which is used for the card transaction.
        cryptogram (str): Base-64 cryptographic identifier used by card
            schemes to validate the token verification result. This is a
            conditionally required field if authentication_method is
            CRYPTOGRAM_3DS.
        eci_indicator (str): Electronic Commerce Indicator may not always be
            present. It is only returned for tokens on the Visa card network.
            This value is passed through in the payment authorization
            request.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_method": 'payment_method',
        "authentication_method": 'authentication_method',
        "message_id": 'message_id',
        "message_expiration": 'message_expiration',
        "cryptogram": 'cryptogram',
        "eci_indicator": 'eci_indicator'
    }

    _optionals = [
        'message_id',
        'message_expiration',
        'cryptogram',
        'eci_indicator',
    ]

    def __init__(self,
                 payment_method=None,
                 authentication_method=None,
                 message_id=APIHelper.SKIP,
                 message_expiration=APIHelper.SKIP,
                 cryptogram=APIHelper.SKIP,
                 eci_indicator=APIHelper.SKIP):
        """Constructor for the GooglePayDecryptedTokenData class"""

        # Initialize members of the class
        if message_id is not APIHelper.SKIP:
            self.message_id = message_id 
        if message_expiration is not APIHelper.SKIP:
            self.message_expiration = message_expiration 
        self.payment_method = payment_method 
        self.authentication_method = authentication_method 
        if cryptogram is not APIHelper.SKIP:
            self.cryptogram = cryptogram 
        if eci_indicator is not APIHelper.SKIP:
            self.eci_indicator = eci_indicator 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_method = dictionary.get("payment_method") if dictionary.get("payment_method") else None
        authentication_method = dictionary.get("authentication_method") if dictionary.get("authentication_method") else None
        message_id = dictionary.get("message_id") if dictionary.get("message_id") else APIHelper.SKIP
        message_expiration = dictionary.get("message_expiration") if dictionary.get("message_expiration") else APIHelper.SKIP
        cryptogram = dictionary.get("cryptogram") if dictionary.get("cryptogram") else APIHelper.SKIP
        eci_indicator = dictionary.get("eci_indicator") if dictionary.get("eci_indicator") else APIHelper.SKIP
        # Return an object of this model
        return cls(payment_method,
                   authentication_method,
                   message_id,
                   message_expiration,
                   cryptogram,
                   eci_indicator)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money


class ShippingOption(object):

    """Implementation of the 'Shipping Option' model.

    The options that the payee or merchant offers to the payer to ship or pick
    up their items.

    Attributes:
        id (str): A unique ID that identifies a payer-selected shipping
            option.
        label (str): A description that the payer sees, which helps them
            choose an appropriate shipping option. For example, `Free
            Shipping`, `USPS Priority Shipping`, `Expédition prioritaire
            USPS`, or `USPS yōuxiān fā huò`. Localize this description to the
            payer's locale.
        mtype (ShippingType): A classification for the method of purchase
            fulfillment.
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        selected (bool): If the API request sets `selected = true`, it
            represents the shipping option that the payee or merchant expects
            to be pre-selected for the payer when they first view the
            `shipping.options` in the PayPal Checkout experience. As part of
            the response if a `shipping.option` contains `selected=true`, it
            represents the shipping option that the payer selected during the
            course of checkout with PayPal. Only one `shipping.option` can be
            set to `selected=true`.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "label": 'label',
        "selected": 'selected',
        "mtype": 'type',
        "amount": 'amount'
    }

    _optionals = [
        'mtype',
        'amount',
    ]

    def __init__(self,
                 id=None,
                 label=None,
                 selected=None,
                 mtype=APIHelper.SKIP,
                 amount=APIHelper.SKIP):
        """Constructor for the ShippingOption class"""

        # Initialize members of the class
        self.id = id 
        self.label = label 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if amount is not APIHelper.SKIP:
            self.amount = amount 
        self.selected = selected 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else None
        label = dictionary.get("label") if dictionary.get("label") else None
        selected = dictionary.get("selected") if "selected" in dictionary.keys() else None
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        amount = Money.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   label,
                   selected,
                   mtype,
                   amount)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.order_tracker_item import OrderTrackerItem


class OrderTrackerRequest(object):

    """Implementation of the 'Order Tracker Request' model.

    The tracking details of an order.

    Attributes:
        tracking_number (str): The tracking number for the shipment. This
            property supports Unicode.
        carrier (ShipmentCarrier): The carrier for the shipment. Some carriers
            have a global version as well as local subsidiaries. The
            subsidiaries are repeated over many countries and might also have
            an entry in the global list. Choose the carrier for your country.
            If the carrier is not available for your country, choose the
            global version of the carrier. If your carrier name is not in the
            list, set `carrier` to `OTHER` and set carrier name in
            `carrier_name_other`. For allowed values, see <a
            href="/docs/tracking/reference/carriers/">Carriers</a>.
        carrier_name_other (str): The name of the carrier for the shipment.
            Provide this value only if the carrier parameter is OTHER. This
            property supports Unicode.
        capture_id (str): The PayPal capture ID.
        notify_payer (bool): If true, sends an email notification to the payer
            of the PayPal transaction. The email contains the tracking
            information that was uploaded through the API.
        items (List[OrderTrackerItem]): An array of details of items in the
            shipment.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "capture_id": 'capture_id',
        "tracking_number": 'tracking_number',
        "carrier": 'carrier',
        "carrier_name_other": 'carrier_name_other',
        "notify_payer": 'notify_payer',
        "items": 'items'
    }

    _optionals = [
        'tracking_number',
        'carrier',
        'carrier_name_other',
        'notify_payer',
        'items',
    ]

    def __init__(self,
                 capture_id=None,
                 tracking_number=APIHelper.SKIP,
                 carrier=APIHelper.SKIP,
                 carrier_name_other=APIHelper.SKIP,
                 notify_payer=False,
                 items=APIHelper.SKIP):
        """Constructor for the OrderTrackerRequest class"""

        # Initialize members of the class
        if tracking_number is not APIHelper.SKIP:
            self.tracking_number = tracking_number 
        if carrier is not APIHelper.SKIP:
            self.carrier = carrier 
        if carrier_name_other is not APIHelper.SKIP:
            self.carrier_name_other = carrier_name_other 
        self.capture_id = capture_id 
        self.notify_payer = notify_payer 
        if items is not APIHelper.SKIP:
            self.items = items 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        capture_id = dictionary.get("capture_id") if dictionary.get("capture_id") else None
        tracking_number = dictionary.get("tracking_number") if dictionary.get("tracking_number") else APIHelper.SKIP
        carrier = dictionary.get("carrier") if dictionary.get("carrier") else APIHelper.SKIP
        carrier_name_other = dictionary.get("carrier_name_other") if dictionary.get("carrier_name_other") else APIHelper.SKIP
        notify_payer = dictionary.get("notify_payer") if dictionary.get("notify_payer") else False
        items = None
        if dictionary.get('items') is not None:
            items = [OrderTrackerItem.from_dictionary(x) for x in dictionary.get('items')]
        else:
            items = APIHelper.SKIP
        # Return an object of this model
        return cls(capture_id,
                   tracking_number,
                   carrier,
                   carrier_name_other,
                   notify_payer,
                   items)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class VaultInstructionBase(object):

    """Implementation of the 'Vault Instruction Base' model.

    Basic vault instruction specification that can be extended by specific
    payment sources that supports vaulting.

    Attributes:
        store_in_vault (StoreInVaultInstruction): Defines how and when the
            payment source gets vaulted.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "store_in_vault": 'store_in_vault'
    }

    _optionals = [
        'store_in_vault',
    ]

    def __init__(self,
                 store_in_vault=APIHelper.SKIP):
        """Constructor for the VaultInstructionBase class"""

        # Initialize members of the class
        if store_in_vault is not APIHelper.SKIP:
            self.store_in_vault = store_in_vault 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        store_in_vault = dictionary.get("store_in_vault") if dictionary.get("store_in_vault") else APIHelper.SKIP
        # Return an object of this model
        return cls(store_in_vault)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.pay_pal_payment_token import PayPalPaymentToken
from paypalserversdk.models.setup_token_response_card import SetupTokenResponseCard
from paypalserversdk.models.venmo_payment_token import VenmoPaymentToken


class SetupTokenResponsePaymentSource(object):

    """Implementation of the 'Setup Token Response Payment Source' model.

    The setup payment method details.

    Attributes:
        card (SetupTokenResponseCard): TODO: type description here.
        paypal (PayPalPaymentToken): TODO: type description here.
        venmo (VenmoPaymentToken): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "card": 'card',
        "paypal": 'paypal',
        "venmo": 'venmo'
    }

    _optionals = [
        'card',
        'paypal',
        'venmo',
    ]

    def __init__(self,
                 card=APIHelper.SKIP,
                 paypal=APIHelper.SKIP,
                 venmo=APIHelper.SKIP):
        """Constructor for the SetupTokenResponsePaymentSource class"""

        # Initialize members of the class
        if card is not APIHelper.SKIP:
            self.card = card 
        if paypal is not APIHelper.SKIP:
            self.paypal = paypal 
        if venmo is not APIHelper.SKIP:
            self.venmo = venmo 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        card = SetupTokenResponseCard.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        paypal = PayPalPaymentToken.from_dictionary(dictionary.get('paypal')) if 'paypal' in dictionary.keys() else APIHelper.SKIP
        venmo = VenmoPaymentToken.from_dictionary(dictionary.get('venmo')) if 'venmo' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(card,
                   paypal,
                   venmo)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class SupplementaryPurchaseData(object):

    """Implementation of the 'Supplementary Purchase Data' model.

    The capture identification-related fields. Includes the invoice ID, custom
    ID, note to payer, and soft descriptor.

    Attributes:
        invoice_id (str): The API caller-provided external invoice number for
            this order. Appears in both the payer's transaction history and
            the emails that the payer receives.
        note_to_payer (str): An informational note about this settlement.
            Appears in both the payer's transaction history and the emails
            that the payer receives.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "invoice_id": 'invoice_id',
        "note_to_payer": 'note_to_payer'
    }

    _optionals = [
        'invoice_id',
        'note_to_payer',
    ]

    def __init__(self,
                 invoice_id=APIHelper.SKIP,
                 note_to_payer=APIHelper.SKIP):
        """Constructor for the SupplementaryPurchaseData class"""

        # Initialize members of the class
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if note_to_payer is not APIHelper.SKIP:
            self.note_to_payer = note_to_payer 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        note_to_payer = dictionary.get("note_to_payer") if dictionary.get("note_to_payer") else APIHelper.SKIP
        # Return an object of this model
        return cls(invoice_id,
                   note_to_payer)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class CardExperienceContext(object):

    """Implementation of the 'Card Experience Context' model.

    Customizes the payer experience during the 3DS Approval for payment.

    Attributes:
        return_url (str): Describes the URL.
        cancel_url (str): Describes the URL.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "return_url": 'return_url',
        "cancel_url": 'cancel_url'
    }

    _optionals = [
        'return_url',
        'cancel_url',
    ]

    def __init__(self,
                 return_url=APIHelper.SKIP,
                 cancel_url=APIHelper.SKIP):
        """Constructor for the CardExperienceContext class"""

        # Initialize members of the class
        if return_url is not APIHelper.SKIP:
            self.return_url = return_url 
        if cancel_url is not APIHelper.SKIP:
            self.cancel_url = cancel_url 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        return_url = dictionary.get("return_url") if dictionary.get("return_url") else APIHelper.SKIP
        cancel_url = dictionary.get("cancel_url") if dictionary.get("cancel_url") else APIHelper.SKIP
        # Return an object of this model
        return cls(return_url,
                   cancel_url)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.platform_fee import PlatformFee


class PaymentInstruction(object):

    """Implementation of the 'Payment Instruction' model.

    Any additional payment instructions to be consider during payment
    processing. This processing instruction is applicable for Capturing an
    order or Authorizing an Order.

    Attributes:
        platform_fees (List[PlatformFee]): An array of various fees,
            commissions, tips, or donations. This field is only applicable to
            merchants that been enabled for PayPal Complete Payments Platform
            for Marketplaces and Platforms capability.
        disbursement_mode (DisbursementMode): The funds that are held on
            behalf of the merchant.
        payee_pricing_tier_id (str): This field is only enabled for selected
            merchants/partners to use and provides the ability to trigger a
            specific pricing rate/plan for a payment transaction. The list of
            eligible 'payee_pricing_tier_id' would be provided to you by your
            Account Manager. Specifying values other than the one provided to
            you by your account manager would result in an error.
        payee_receivable_fx_rate_id (str): FX identifier generated returned by
            PayPal to be used for payment processing in order to honor FX rate
            (for eligible integrations) to be used when amount is
            settled/received into the payee account.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "platform_fees": 'platform_fees',
        "disbursement_mode": 'disbursement_mode',
        "payee_pricing_tier_id": 'payee_pricing_tier_id',
        "payee_receivable_fx_rate_id": 'payee_receivable_fx_rate_id'
    }

    _optionals = [
        'platform_fees',
        'disbursement_mode',
        'payee_pricing_tier_id',
        'payee_receivable_fx_rate_id',
    ]

    def __init__(self,
                 platform_fees=APIHelper.SKIP,
                 disbursement_mode='INSTANT',
                 payee_pricing_tier_id=APIHelper.SKIP,
                 payee_receivable_fx_rate_id=APIHelper.SKIP):
        """Constructor for the PaymentInstruction class"""

        # Initialize members of the class
        if platform_fees is not APIHelper.SKIP:
            self.platform_fees = platform_fees 
        self.disbursement_mode = disbursement_mode 
        if payee_pricing_tier_id is not APIHelper.SKIP:
            self.payee_pricing_tier_id = payee_pricing_tier_id 
        if payee_receivable_fx_rate_id is not APIHelper.SKIP:
            self.payee_receivable_fx_rate_id = payee_receivable_fx_rate_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        platform_fees = None
        if dictionary.get('platform_fees') is not None:
            platform_fees = [PlatformFee.from_dictionary(x) for x in dictionary.get('platform_fees')]
        else:
            platform_fees = APIHelper.SKIP
        disbursement_mode = dictionary.get("disbursement_mode") if dictionary.get("disbursement_mode") else 'INSTANT'
        payee_pricing_tier_id = dictionary.get("payee_pricing_tier_id") if dictionary.get("payee_pricing_tier_id") else APIHelper.SKIP
        payee_receivable_fx_rate_id = dictionary.get("payee_receivable_fx_rate_id") if dictionary.get("payee_receivable_fx_rate_id") else APIHelper.SKIP
        # Return an object of this model
        return cls(platform_fees,
                   disbursement_mode,
                   payee_pricing_tier_id,
                   payee_receivable_fx_rate_id)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class NetworkToken(object):

    """Implementation of the 'Network Token' model.

    The Third Party Network token used to fund a payment.

    Attributes:
        number (str): Third party network token number.
        expiry (str): The year and month, in ISO-8601 `YYYY-MM` date format.
            See [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6).
        cryptogram (str): An Encrypted one-time use value that's sent along
            with Network Token. This field is not required to be present for
            recurring transactions.
        eci_flag (ECIFlag): Electronic Commerce Indicator (ECI). The ECI value
            is part of the 2 data elements that indicate the transaction was
            processed electronically. This should be passed on the
            authorization transaction to the Gateway/Processor.
        token_requestor_id (str): A TRID, or a Token Requestor ID, is an
            identifier used by merchants to request network tokens from card
            networks. A TRID is a precursor to obtaining a network token for a
            credit card primary account number (PAN), and will aid in enabling
            secure card on file (COF) payments and reducing fraud.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "number": 'number',
        "expiry": 'expiry',
        "cryptogram": 'cryptogram',
        "eci_flag": 'eci_flag',
        "token_requestor_id": 'token_requestor_id'
    }

    _optionals = [
        'cryptogram',
        'eci_flag',
        'token_requestor_id',
    ]

    def __init__(self,
                 number=None,
                 expiry=None,
                 cryptogram=APIHelper.SKIP,
                 eci_flag=APIHelper.SKIP,
                 token_requestor_id=APIHelper.SKIP):
        """Constructor for the NetworkToken class"""

        # Initialize members of the class
        self.number = number 
        self.expiry = expiry 
        if cryptogram is not APIHelper.SKIP:
            self.cryptogram = cryptogram 
        if eci_flag is not APIHelper.SKIP:
            self.eci_flag = eci_flag 
        if token_requestor_id is not APIHelper.SKIP:
            self.token_requestor_id = token_requestor_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        number = dictionary.get("number") if dictionary.get("number") else None
        expiry = dictionary.get("expiry") if dictionary.get("expiry") else None
        cryptogram = dictionary.get("cryptogram") if dictionary.get("cryptogram") else APIHelper.SKIP
        eci_flag = dictionary.get("eci_flag") if dictionary.get("eci_flag") else APIHelper.SKIP
        token_requestor_id = dictionary.get("token_requestor_id") if dictionary.get("token_requestor_id") else APIHelper.SKIP
        # Return an object of this model
        return cls(number,
                   expiry,
                   cryptogram,
                   eci_flag,
                   token_requestor_id)



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money
from paypalserversdk.models.universal_product_code import UniversalProductCode


class LineItem(object):

    """Implementation of the 'Line Item' model.

    The line items for this purchase. If your merchant account has been
    configured for Level 3 processing this field will be passed to the
    processor on your behalf.

    Attributes:
        name (str): The item name or title.
        quantity (str): The item quantity. Must be a whole number.
        description (str): The detailed item description.
        sku (str): The stock keeping unit (SKU) for the item.
        url (str): The URL to the item being purchased. Visible to buyer and
            used in buyer experiences.
        image_url (str): The URL of the item's image. File type and size
            restrictions apply. An image that violates these restrictions will
            not be honored.
        upc (UniversalProductCode): The Universal Product Code of the item.
        unit_amount (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        tax (Money): The currency and amount for a financial transaction, such
            as a balance or payment due.
        commodity_code (str): Code used to classify items purchased and track
            the total amount spent across various categories of products and
            services. Different corporate purchasing organizations may use
            different standards, but the United Nations Standard Products and
            Services Code (UNSPSC) is frequently used.
        discount_amount (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        total_amount (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        unit_of_measure (str): Unit of measure is a standard used to express
            the magnitude of a quantity in international trade. Most commonly
            used (but not limited to) examples are: Acre (ACR), Ampere (AMP),
            Centigram (CGM), Centimetre (CMT), Cubic inch (INQ), Cubic metre
            (MTQ), Fluid ounce (OZA), Foot (FOT), Hour (HUR), Item (ITM),
            Kilogram (KGM), Kilometre (KMT), Kilowatt (KWT), Liquid gallon
            (GLL), Liter (LTR), Pounds (LBS), Square foot (FTK).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "quantity": 'quantity',
        "description": 'description',
        "sku": 'sku',
        "url": 'url',
        "image_url": 'image_url',
        "upc": 'upc',
        "unit_amount": 'unit_amount',
        "tax": 'tax',
        "commodity_code": 'commodity_code',
        "discount_amount": 'discount_amount',
        "total_amount": 'total_amount',
        "unit_of_measure": 'unit_of_measure'
    }

    _optionals = [
        'description',
        'sku',
        'url',
        'image_url',
        'upc',
        'unit_amount',
        'tax',
        'commodity_code',
        'discount_amount',
        'total_amount',
        'unit_of_measure',
    ]

    def __init__(self,
                 name=None,
                 quantity=None,
                 description=APIHelper.SKIP,
                 sku=APIHelper.SKIP,
                 url=APIHelper.SKIP,
                 image_url=APIHelper.SKIP,
                 upc=APIHelper.SKIP,
                 unit_amount=APIHelper.SKIP,
                 tax=APIHelper.SKIP,
                 commodity_code=APIHelper.SKIP,
                 discount_amount=APIHelper.SKIP,
                 total_amount=APIHelper.SKIP,
                 unit_of_measure=APIHelper.SKIP):
        """Constructor for the LineItem class"""

        # Initialize members of the class
        self.name = name 
        self.quantity = quantity 
        if description is not APIHelper.SKIP:
            self.description = description 
        if sku is not APIHelper.SKIP:
            self.sku = sku 
        if url is not APIHelper.SKIP:
            self.url = url 
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url 
        if upc is not APIHelper.SKIP:
            self.upc = upc 
        if unit_amount is not APIHelper.SKIP:
            self.unit_amount = unit_amount 
        if tax is not APIHelper.SKIP:
            self.tax = tax 
        if commodity_code is not APIHelper.SKIP:
            self.commodity_code = commodity_code 
        if discount_amount is not APIHelper.SKIP:
            self.discount_amount = discount_amount 
        if total_amount is not APIHelper.SKIP:
            self.total_amount = total_amount 
        if unit_of_measure is not APIHelper.SKIP:
            self.unit_of_measure = unit_of_measure 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else None
        quantity = dictionary.get("quantity") if dictionary.get("quantity") else None
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        sku = dictionary.get("sku") if dictionary.get("sku") else APIHelper.SKIP
        url = dictionary.get("url") if dictionary.get("url") else APIHelper.SKIP
        image_url = dictionary.get("image_url") if dictionary.get("image_url") else APIHelper.SKIP
        upc = UniversalProductCode.from_dictionary(dictionary.get('upc')) if 'upc' in dictionary.keys() else APIHelper.SKIP
        unit_amount = Money.from_dictionary(dictionary.get('unit_amount')) if 'unit_amount' in dictionary.keys() else APIHelper.SKIP
        tax = Money.from_dictionary(dictionary.get('tax')) if 'tax' in dictionary.keys() else APIHelper.SKIP
        commodity_code = dictionary.get("commodity_code") if dictionary.get("commodity_code") else APIHelper.SKIP
        discount_amount = Money.from_dictionary(dictionary.get('discount_amount')) if 'discount_amount' in dictionary.keys() else APIHelper.SKIP
        total_amount = Money.from_dictionary(dictionary.get('total_amount')) if 'total_amount' in dictionary.keys() else APIHelper.SKIP
        unit_of_measure = dictionary.get("unit_of_measure") if dictionary.get("unit_of_measure") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   quantity,
                   description,
                   sku,
                   url,
                   image_url,
                   upc,
                   unit_amount,
                   tax,
                   commodity_code,
                   discount_amount,
                   total_amount,
                   unit_of_measure)
